#!/usr/bin/perl -w
use strict;
#use diagnostics;

# Copyright 2004 Frederick Dean

use lib "..";
use FKong::db;
require "featurekong_startup.pl";

(my $exedir = $0) =~ s/[^\/]+$//;  # delete filename
chdir($exedir); 

my $dbh = FKong::db::SendSQL("SHOW TABLES");
my @tables;
while(my $table = $dbh->fetchrow_array()) {
   next if $table eq "user";
   next if $table eq "session";
   push(@tables,$table); 
}
foreach my $table (@tables) {
   print("drop table $table\n");
   FKong::db::SendSQL("DROP TABLE IF EXISTS $table");
}

FKong::db::SendSQL("DELETE FROM user WHERE userid IN (97,98,99)");

chdir("..");
system("./checksetup.pl");
$? and die;
chmod(0775, glob("reset*"));
chmod(0775, glob("test*"));
chmod(0775, glob("*.pl"));


chdir("test");
system("./garbage_features.pl --dataloss");


